package cd.casic.ci.common.pipeline.container;

import cd.casic.ci.common.pipeline.pojo.BuildFormProperty;
import cd.casic.ci.common.pipeline.pojo.BuildNo;
import cd.casic.ci.common.pipeline.pojo.element.Element;
import cd.casic.ci.common.pipeline.pojo.time.BuildRecordTimeCost;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.List;
import java.util.Map;

/**
 * @Author：mianbin
 * @Package：cd.casic.ci.common.pipeline.container
 * @Project：ops-pro
 * @name：TriggerContainer
 * @Date：2025/03/25 16:56
 * @Filename：TriggerContainer
 * @description：Todo
 */
@Data
@NoArgsConstructor
@Schema(title = "流水线模型-构建触发容器")
public class TriggerContainer extends Container {
    public static final String classType = "trigger";

    @Schema(title = "构建容器序号id", required = false, readOnly = true)
    private String id;
    @Schema(title = "容器名称", required = true)
    private String name;
    @Schema(title = "任务集合", required = true)
    private List<Element> elements;
    @Schema(title = "状态", required = true, readOnly = true)
    private String status;
    @Schema(title = "系统运行时间", required = false)
    @Deprecated
    private Long startEpoch;
    @Schema(title = "系统耗时（开机时间）", required = false, readOnly = true)
    @Deprecated
    private Long systemElapsed;
    @Schema(title = "插件执行耗时", required = false, readOnly = true)
    @Deprecated
    private Long elementElapsed;
    @Schema(title = "参数化构建", required = false)
    private List<BuildFormProperty> params;
    @Schema(title = "模板参数构建", required = false)
    private List<BuildFormProperty> templateParams;
    @Schema(title = "构建版本号", required = false)
    private BuildNo buildNo;
    @Schema(title = "是否可重试-仅限于构建详情展示重试，目前未作为编排的选项，暂设置为null不存储", required = false, readOnly = true)
    private Boolean canRetry;
    @Schema(title = "构建容器顺序ID（同id值）", required = false, readOnly = true)
    private String containerId;
    @Schema(title = "容器唯一ID", required = false, readOnly = true)
    private String containerHashId;
    @Schema(title = "构建环境启动状态", required = false, readOnly = true)
    private String startVMStatus;
    @Schema(title = "容器运行次数", required = false, readOnly = true)
    private Integer executeCount;
    @Schema(title = "用户自定义ID", required = false, hidden = false)
    private String jobId;
    @Schema(title = "是否包含post任务标识", required = false, readOnly = true)
    private Boolean containPostTaskFlag;
    @Schema(title = "是否为构建矩阵", required = false, readOnly = true)
    private Boolean matrixGroupFlag;
    @Schema(title = "各项耗时", required = true)
    private BuildRecordTimeCost timeCost;
    @Schema(title = "开机任务序号", required = false, readOnly = true)
    private Integer startVMTaskSeq;

    @Override
    public String getClassType() {
        return classType;
    }

    @Override
    public Container getContainerById(String vmSeqId) {
        return id.equals(vmSeqId) ? this : null;
    }

    @Override
    public void retryFreshMatrixOption() {
        // No operation needed
    }

    @Override
    public List<Container> fetchGroupContainers() {
        return null;
    }

    @Override
    public Map<String, String> fetchMatrixContext() {
        return null;
    }

    @Override
    public boolean containerEnabled() {
        return true;
    }

    @Override
    public void setContainerEnable(boolean enable) {

    }

    @Override
    public void transformCompatibility() {
        // No compatibility transformation needed
    }

    @Override
    public String getTemplate() {
        return null;
    }

    @Override
    public String getRef() {
        return null;
    }

    @Override
    public Map<String, String> getVariables() {
        return null;
    }

    @Override
    public void setTemplate(String template) {

    }

    @Override
    public void setRef(String ref) {

    }

    @Override
    public void setVariables(Map<String, String> variables) {

    }
}
