package cd.casic.ci.common.pipeline.container;

import cd.casic.ci.common.pipeline.NameAndValue;
import cd.casic.ci.common.pipeline.enums.VMBaseOS;
import cd.casic.ci.common.pipeline.option.JobControlOption;
import cd.casic.ci.common.pipeline.option.MatrixControlOption;
import cd.casic.ci.common.pipeline.pojo.element.Element;
import cd.casic.ci.common.pipeline.pojo.time.BuildRecordTimeCost;
import cd.casic.ci.common.pipeline.type.DispatchType;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * @Author：mianbin
 * @Package：cd.casic.ci.common.pipeline.container
 * @Project：ops-pro
 * @name：VMBuildContainer
 * @Date：2025/03/25 16:56
 * @Filename：VMBuildContainer
 * @description：Todo
 */
@Data
@NoArgsConstructor
@Schema(title = "流水线模型-虚拟机构建容器")
public class VMBuildContainer extends Container {
    public static final String classType = "vmBuild";

    @Schema(title = "构建容器序号id", required = false, readOnly = true)
    private String id;
    @Schema(title = "容器名称", required = true)
    private String name = "构建环境";
    @Schema(title = "任务集合", required = true)
    private List<Element> elements;
    @Schema(title = "容器状态", required = false, readOnly = true)
    private String status;
    @Schema(title = "系统运行时间", required = false, readOnly = true)
    @Deprecated
    private Long startEpoch;
    @Schema(title = "系统耗时（开机时间）", required = false, readOnly = true)
    @Deprecated
    private Long systemElapsed;
    @Schema(title = "插件执行耗时", required = false, readOnly = true)
    @Deprecated
    private Long elementElapsed;
    @Schema(title = "VM基础操作系统", required = true)
    private VMBaseOS baseOS;
    @Schema(title = "预指定VM名称列表", required = true)
    private Set<String> vmNames;
    @Schema(title = "排队最长时间(分钟)", required = true)
    @Deprecated
    private Integer maxQueueMinutes = 60;
    @Schema(title = "运行最长时间(分钟)", required = true)
    @Deprecated
    private Integer maxRunningMinutes = 480;
    @Schema(title = "构建机环境变量（容器启动时写入环境）", required = false)
    private Map<String, String> buildEnv;
    @Schema(title = "用户自定义环境变量（Agent启动时写入环境）", required = false)
    @Deprecated
    private Map<String, String> customBuildEnv;
    @Schema(title = "用户自定义环境变量（Agent启动时写入环境）", required = false)
    private List<NameAndValue> customEnv;
    @Schema(title = "第三方构建Hash ID", required = false)
    private String thirdPartyAgentId;
    @Schema(title = "第三方构建环境ID", required = false)
    private String thirdPartyAgentEnvId;
    @Schema(title = "第三方构建环境工作空间", required = false)
    private String thirdPartyWorkspace;
    @Schema(title = "Docker构建机", required = false)
    private String dockerBuildVersion;
    @Schema(title = "TStack Hash Id", required = false)
    @Deprecated
    private String tstackAgentId;
    @Schema(title = "新的选择构建机环境", required = false)
    private DispatchType dispatchType;
    @Schema(title = "是否显示构建资源信息", required = false)
    private Boolean showBuildResource;
    @Schema(title = "是否访问外网", required = false, readOnly = true)
    private Boolean enableExternal;
    @Schema(title = "构建容器顺序ID（同id值）", required = false, readOnly = true)
    private String containerId;
    @Schema(title = "容器唯一ID", required = false, readOnly = true)
    private String containerHashId;
    @Schema(title = "流程控制选项", required = true)
    private JobControlOption jobControlOption;
    @Schema(title = "互斥组", required = false)
    private MutexGroup mutexGroup;
    @Schema(title = "构建环境启动状态", required = false, readOnly = true)
    private String startVMStatus;
    @Schema(title = "容器运行次数", required = false, readOnly = true)
    private Integer executeCount;
    @Schema(title = "用户自定义ID", required = false, hidden = false)
    private String jobId;
    @Schema(title = "是否包含post任务标识", required = false, readOnly = true)
    private Boolean containPostTaskFlag;
    @Schema(title = "是否为构建矩阵", required = false, readOnly = true)
    private Boolean matrixGroupFlag;
    @Schema(title = "各项耗时", required = true)
    private BuildRecordTimeCost timeCost;
    @Schema(title = "开机任务序号", required = false, readOnly = true)
    private Integer startVMTaskSeq;
    @Schema(title = "构建矩阵配置项", required = false)
    private MatrixControlOption matrixControlOption;
    @Schema(title = "所在构建矩阵组的containerHashId（分裂后的子容器特有字段）", required = false)
    private String matrixGroupId;
    @Schema(title = "当前矩阵子容器的上下文组合（分裂后的子容器特有字段）", required = false)
    private Map<String, String> matrixContext;
    @Schema(title = "分裂后的容器集合（分裂后的父容器特有字段）", required = false)
    private List<VMBuildContainer> groupContainers;
    @Schema(title = "nfs挂载开关", required = false, readOnly = true)
    private Boolean nfsSwitch;

    public Boolean getNfsSwitch() {
        return nfsSwitch != null ? nfsSwitch : true;
    }

    @Override
    public String getClassType() {
        return classType;
    }

    @Override
    public Container getContainerById(String vmSeqId) {
        if (id.equals(vmSeqId) || containerId.equals(vmSeqId)) return this;
        if (groupContainers != null) {
            for (Container container : groupContainers) {
                if (container.getId().equals(vmSeqId) || container.getContainerId().equals(vmSeqId)) return container;
            }
        }
        return null;
    }

    @Override
    public void retryFreshMatrixOption() {
        groupContainers = new ArrayList<>();
        if (matrixControlOption != null) {
            matrixControlOption.setFinishCount(null);
            matrixControlOption.setTotalCount(null);
        }
    }

    @Override
    public List<Container> fetchGroupContainers() {
        return groupContainers != null ? new ArrayList<>(groupContainers) : null;
    }

    @Override
    public Map<String, String> fetchMatrixContext() {
        return matrixContext;
    }

    @Override
    public boolean containerEnabled() {
        return jobControlOption != null ? jobControlOption.getEnable() : true;
    }

    @Override
    public void setContainerEnable(boolean enable) {

    }

    @Override
    public void transformCompatibility() {
        if (jobControlOption != null && jobControlOption.getTimeoutVar() == null || jobControlOption.getTimeoutVar().isBlank()) {
            jobControlOption.setTimeoutVar(String.valueOf(jobControlOption.getTimeout()));
        }
        if (mutexGroup != null && (mutexGroup.getTimeoutVar() == null || mutexGroup.getTimeoutVar().isBlank())) {
            mutexGroup.setTimeoutVar(String.valueOf(mutexGroup.getTimeout()));
        }
    }

    @Override
    public String getTemplate() {
        return null;
    }

    @Override
    public String getRef() {
        return null;
    }

    @Override
    public Map<String, String> getVariables() {
        return null;
    }

    @Override
    public void setTemplate(String template) {

    }

    @Override
    public void setRef(String ref) {

    }

    @Override
    public void setVariables(Map<String, String> variables) {

    }
}
