package cd.casic.ci.common.pipeline.pojo.element.trigger;

import cd.casic.ci.common.pipeline.enums.StartType;
import cd.casic.ci.common.pipeline.enums.TriggerRepositoryType;
import cd.casic.ci.common.pipeline.pojo.element.ElementProp;
import cd.casic.ci.common.pipeline.pojo.element.trigger.enums.CodeEventType;
import cd.casic.ci.common.pipeline.pojo.element.trigger.enums.PathFilterType;
import cd.casic.ci.common.pipeline.utils.TriggerElementPropUtils;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.experimental.Accessors;

import java.util.List;

/**
 * @Author：mianbin
 * @Package：cd.casic.ci.common.pipeline.pojo.element.trigger
 * @Project：ops-pro
 * @name：CodeTGitWebHookTriggerElement
 * @Date：2025/03/27 10:05
 * @Filename：CodeTGitWebHookTriggerElement
 * @description：Todo
 */
@Accessors(chain = true)
@Schema(title = "TGit事件触发", description = CodeTGitWebHookTriggerElement.classType)
public class CodeTGitWebHookTriggerElement extends WebHookTriggerElement {
    public static final String classType = "codeTGitWebHookTrigger";

    @Schema(title = "任务名称", required = true)
    private String name = "TGit事件触发";

    @Schema(title = "id", required = false)
    private String id;

    @Schema(title = "状态", required = false)
    private String status;

    @Schema(title = "数据", required = true)
    private CodeTGitWebHookTriggerData data;

    public CodeTGitWebHookTriggerElement(String name, String id, String status) {
        super(name, id, status);
    }

    @Override
    public String getClassType() {
        return classType;
    }

    @Override
    public String findFirstTaskIdByStartType(StartType startType) {
        return StartType.WEB_HOOK.name().equals(startType.name()) ? this.id : super.findFirstTaskIdByStartType(startType);
    }

    @Override
    public List<ElementProp> triggerCondition() {
        CodeTGitWebHookTriggerInput input = data.getInput();
        List<ElementProp> props;
        switch (input.getEventType()) {
            case PUSH:
                props = List.of(
                        TriggerElementPropUtils.vuexInput("action", joinToString(input.getIncludePushAction())),
                        TriggerElementPropUtils.vuexInput("branchName", input.getBranchName()),
                        TriggerElementPropUtils.vuexInput("excludeBranchName", input.getExcludeBranchName()),
                        TriggerElementPropUtils.vuexInput("includePaths", input.getIncludePaths()),
                        TriggerElementPropUtils.vuexInput("excludePaths", input.getExcludePaths()),
                        TriggerElementPropUtils.staffInput("includeUsers", input.getIncludeUsers()),
                        TriggerElementPropUtils.staffInput("excludeUsers", input.getExcludeUsers())
                );
                break;
            case MERGE_REQUEST:
                props = List.of(
                        TriggerElementPropUtils.vuexInput("action", joinToString(input.getIncludeMrAction())),
                        TriggerElementPropUtils.selector("skip-wip", List.of((input.getSkipWip() != null ? input.getSkipWip().toString() : "false"))),
                        TriggerElementPropUtils.vuexInput("branchName", input.getBranchName()),
                        TriggerElementPropUtils.vuexInput("excludeBranchName", input.getExcludeBranchName()),
                        TriggerElementPropUtils.vuexInput("includeSourceBranchName", input.getIncludeSourceBranchName()),
                        TriggerElementPropUtils.vuexInput("includeSourceBranchName", input.getIncludeSourceBranchName()),
                        TriggerElementPropUtils.vuexInput("includePaths", input.getIncludePaths()),
                        TriggerElementPropUtils.vuexInput("excludePaths", input.getExcludePaths()),
                        TriggerElementPropUtils.staffInput("includeUsers", input.getIncludeUsers()),
                        TriggerElementPropUtils.staffInput("excludeUsers", input.getExcludeUsers())
                );
                break;
            case MERGE_REQUEST_ACCEPT:
                props = List.of(
                        TriggerElementPropUtils.vuexInput("action", "merge"),
                        TriggerElementPropUtils.vuexInput("branchName", input.getBranchName()),
                        TriggerElementPropUtils.vuexInput("excludeBranchName", input.getExcludeBranchName()),
                        TriggerElementPropUtils.vuexInput("includeSourceBranchName", input.getIncludeSourceBranchName()),
                        TriggerElementPropUtils.vuexInput("includeSourceBranchName", input.getIncludeSourceBranchName()),
                        TriggerElementPropUtils.vuexInput("includePaths", input.getIncludePaths()),
                        TriggerElementPropUtils.vuexInput("excludePaths", input.getExcludePaths()),
                        TriggerElementPropUtils.staffInput("includeUsers", input.getIncludeUsers()),
                        TriggerElementPropUtils.staffInput("excludeUsers", input.getExcludeUsers())
                );
                break;
            case TAG_PUSH:
                props = List.of(
                        TriggerElementPropUtils.vuexInput("tagName", input.getTagName()),
                        TriggerElementPropUtils.vuexInput("excludeTagName", input.getExcludeTagName()),
                        TriggerElementPropUtils.vuexInput("fromBranches", input.getFromBranches()),
                        TriggerElementPropUtils.staffInput("includeUsers", input.getIncludeUsers()),
                        TriggerElementPropUtils.staffInput("excludeUsers", input.getExcludeUsers())
                );
                break;
            case REVIEW:
                props = List.of(
                        TriggerElementPropUtils.selector("includeCrState", input.getIncludeCrState())
                );
                break;
            case ISSUES:
                props = List.of(
                        TriggerElementPropUtils.selector("includeIssueAction", input.getIncludeIssueAction())
                );
                break;
            case NOTE:
                props = List.of(
                        TriggerElementPropUtils.selector("includeNoteTypes", input.getIncludeNoteTypes()),
                        TriggerElementPropUtils.vuexInput("includeNoteComment", input.getIncludeNoteComment())
                );
                break;
            default:
                props = List.of();
        }
        return props.stream().filter(java.util.Objects::nonNull).toList();
    }
}

@Data
@Accessors(chain = true)
class CodeTGitWebHookTriggerData {
    private CodeTGitWebHookTriggerInput input;
}

@Data
@Accessors(chain = true)
class CodeTGitWebHookTriggerInput {
    @Schema(title = "仓库ID", required = true)
    private String repositoryHashId;

    @Schema(title = "分支名称", required = false)
    private String branchName;

    @Schema(title = "用于排除的分支名", required = false)
    private String excludeBranchName;

    @Schema(title = "路径过滤类型", required = true)
    private PathFilterType pathFilterType = PathFilterType.NamePrefixFilter;

    @Schema(title = "用于包含的路径", required = false)
    private String includePaths;

    @Schema(title = "用于排除的路径", required = false)
    private String excludePaths;

    @Schema(title = "用户白名单", required = false)
    private List<String> includeUsers;

    @Schema(title = "用于排除的user id", required = false)
    private List<String> excludeUsers;

    @Schema(title = "事件类型", required = false)
    private CodeEventType eventType;

    @Schema(title = "是否为block", required = false)
    private Boolean block;

    @Schema(title = "新版的git原子的类型")
    private TriggerRepositoryType repositoryType;

    @Schema(title = "新版的git代码库名")
    private String repositoryName;

    @Schema(title = "tag名称", required = false)
    private String tagName;

    @Schema(title = "用于排除的tag名称", required = false)
    private String excludeTagName;

    @Schema(title = "tag从哪条分支创建", required = false)
    private String fromBranches;

    @Schema(title = "用于排除的源分支名称", required = false)
    private String excludeSourceBranchName;

    @Schema(title = "用于包含的源分支名称", required = false)
    private String includeSourceBranchName;

    @Schema(title = "webhook队列", required = false)
    private Boolean webhookQueue = false;

    @Schema(title = "code review 状态", required = false)
    private List<String> includeCrState;

    @Schema(title = "code review 类型", required = false)
    private List<String> includeCrTypes;

    @Schema(title = "code note comment", required = false)
    private String includeNoteComment;

    @Schema(title = "code note 类型", required = false)
    private List<String> includeNoteTypes;

    @Schema(title = "是否启用回写")
    private Boolean enableCheck = true;

    @Schema(title = "issue事件action")
    private List<String> includeIssueAction;

    @Schema(title = "mr事件action")
    private List<String> includeMrAction;

    @Schema(title = "push事件action")
    private List<String> includePushAction;

    @Schema(title = "是否启用第三方过滤")
    private Boolean enableThirdFilter = false;

    @Schema(title = "跳过WIP")
    private Boolean skipWip = false;
}
