package cd.casic.ci.common.pipeline.pojo.element.trigger.enums;


import cd.casic.ci.common.pipeline.enums.ScmType;

import java.util.ArrayList;
import java.util.List;

/**
 * @Author：mianbin
 * @Package：cd.casic.ci.common.pipeline.pojo.element.trigger.enums
 * @Project：ops-pro
 * @name：CodeEventType
 * @Date：2025/03/27 10:26
 * @Filename：CodeEventType
 * @description：Todo
 */
public enum CodeEventType {
    // Git events
    PUSH,
    TAG_PUSH,
    MERGE_REQUEST,
    MERGE_REQUEST_ACCEPT,
    ISSUES,
    NOTE,
    REVIEW,
    // GitHub events
    CREATE,
    PULL_REQUEST,
    // SVN events
    POST_COMMIT,
    LOCK_COMMIT,
    PRE_COMMIT,
    // Perforce (P4) events
    CHANGE_COMMIT,
    PUSH_SUBMIT,
    CHANGE_CONTENT,
    CHANGE_SUBMIT,
    PUSH_CONTENT,
    PUSH_COMMIT,
    FIX_ADD,
    FIX_DELETE,
    FORM_COMMIT,
    SHELVE_COMMIT,
    SHELVE_DELETE,
    SHELVE_SUBMIT,

    // Sub-pipeline
    PARENT_PIPELINE;

    public static final String MESSAGE_CODE_PREFIX = "EVENT_TYPE";

    // Git events
    public static final List<CodeEventType> CODE_GIT_EVENTS = List.of(
            PUSH, MERGE_REQUEST, MERGE_REQUEST_ACCEPT, TAG_PUSH, NOTE, REVIEW, ISSUES
    );

    // GitHub events
    public static final List<CodeEventType> CODE_GITHUB_EVENTS = List.of(
            PUSH, PULL_REQUEST, CREATE, REVIEW, ISSUES, NOTE
    );

    // Perforce (P4) events
    public static final List<CodeEventType> CODE_P4_EVENTS = List.of(
            CHANGE_COMMIT, CHANGE_SUBMIT, CHANGE_CONTENT, SHELVE_COMMIT, SHELVE_SUBMIT
    );

    // GitLab events
    public static final List<CodeEventType> CODE_GITLAB_EVENTS = List.of(
            PUSH, MERGE_REQUEST, MERGE_REQUEST_ACCEPT, TAG_PUSH
    );

    // Tencent Git (TGit) events
    public static final List<CodeEventType> CODE_TGIT_EVENTS = List.of(
            PUSH, MERGE_REQUEST, MERGE_REQUEST_ACCEPT, TAG_PUSH, NOTE, ISSUES
    );

    // SVN events
    public static final List<CodeEventType> CODE_SVN_EVENTS = List.of(
            POST_COMMIT, PRE_COMMIT, LOCK_COMMIT
    );

    public static List<CodeEventType> getEventsByScmType(ScmType scmType) {
        if (scmType == null) {
            return List.of(values());
        }
        switch (scmType) {
            case CODE_GIT:
                return new ArrayList<>(CODE_GIT_EVENTS);
            case CODE_TGIT:
                return new ArrayList<>(CODE_TGIT_EVENTS);
            case GITHUB:
                return new ArrayList<>(CODE_GITHUB_EVENTS);
            case CODE_GITLAB:
                return new ArrayList<>(CODE_GITLAB_EVENTS);
            case CODE_SVN:
                return new ArrayList<>(CODE_SVN_EVENTS);
            case CODE_P4:
                return new ArrayList<>(CODE_P4_EVENTS);
            default:
                return List.of(values());
        }
    }
}
