package cd.casic.pipeline.dispatch.api;


import cd.casic.ci.common.pipeline.pojo.agent.ThirdPartyAgentUpgradeByVersionInfo;
import cd.casic.ci.common.pipeline.pojo.agent.UpgradeItem;
import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.dispatch.pojo.thirdpartyagent.*;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.*;


@Tag(name = "BUILD_AGENT_BUILD", description = "第三方接入agent资源")
@RestController
@RequestMapping("/buildAgent/agent/thirdPartyAgent")
public interface BuildAgentBuildResource {

    @Operation(summary = "尝试启动构建")
    @GetMapping("/startup")
    CommonResult<ThirdPartyBuildInfo> startBuild(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "Agent ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_ID) String agentId,
            @Parameter(description = "秘钥", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_SECRET_KEY) String secretKey,
            @Parameter(description = "尝试启动构建的类型", required = false)
            @RequestParam("buildType") String buildType);

    @Operation(summary = "是否更新")
    @GetMapping("/upgrade")
    CommonResult<Boolean> upgrade(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "Agent ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_ID) String agentId,
            @Parameter(description = "秘钥", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_SECRET_KEY) String secretKey,
            @Parameter(description = "Agent 版本号", required = false)
            @RequestParam("version") String version,
            @Parameter(description = "masterAgent 版本号", required = false)
            @RequestParam("masterVersion") String masterVersion);

    @Operation(summary = "是否更新NEW")
    @PostMapping("/upgradeNew")
    CommonResult<UpgradeItem> upgradeNew(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "Agent ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_ID) String agentId,
            @Parameter(description = "秘钥", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_SECRET_KEY) String secretKey,
            @Parameter(description = "检查版本升级上报的信息", required = false)
            ThirdPartyAgentUpgradeByVersionInfo info);

    @Operation(summary = "更新完成")
    @DeleteMapping("/upgrade")
    CommonResult<Boolean> finishUpgrade(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "Agent ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_ID) String agentId,
            @Parameter(description = "秘钥", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_SECRET_KEY) String secretKey,
            @Parameter(description = "升级是否成功", required = true)
            @RequestParam("success") boolean success);

    @Operation(summary = "worker构建结束")
    @PostMapping("/workerBuildFinish")
    CommonResult<Boolean> workerBuildFinish(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "Agent ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_ID) String agentId,
            @Parameter(description = "秘钥", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_SECRET_KEY) String secretKey,
            @Parameter(description = "构建信息", required = true)
            ThirdPartyBuildWithStatus buildInfo);

    @Operation(summary = "尝试启动Docker登录调试")
    @GetMapping("/docker/startupDebug")
    CommonResult<ThirdPartyDockerDebugInfo> dockerStartDebug(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "Agent ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_ID) String agentId,
            @Parameter(description = "秘钥", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_SECRET_KEY) String secretKey);

    @Operation(summary = "启动Docker登录完成")
    @PostMapping("/docker/startupDebug")
    CommonResult<Boolean> dockerStartDebugDone(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "Agent ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_ID) String agentId,
            @Parameter(description = "秘钥", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_SECRET_KEY) String secretKey,
            @Parameter(description = "构建信息", required = true)
            ThirdPartyDockerDebugDoneInfo debugInfo);

    @Operation(summary = "获取登录调试任务状态")
    @GetMapping("/docker/debug/status")
    CommonResult<String> dockerDebugStatus(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "Agent ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_ID) String agentId,
            @Parameter(description = "秘钥", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_SECRET_KEY) String secretKey,
            @Parameter(description = "debugId", required = true)
            @RequestParam("debugId") long debugId);

    @Operation(summary = "第三方构建机请求")
    @PostMapping("/ask")
    CommonResult<ThirdPartyAskResp> thirdPartyAgentAsk(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "Agent ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_ID) String agentId,
            @Parameter(description = "秘钥", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_SECRET_KEY) String secretKey,
            @Parameter(description = "ask信息", required = true)
            ThirdPartyAskInfo data);
}