package cd.casic.ci.log.service;

import cd.casic.ci.log.dal.pojo.QueryLogStatus;
import cd.casic.ci.log.dal.pojo.TaskBuildLogProperty;
import cd.casic.ci.log.dal.dao.LogStatusMapper;
import cd.casic.ci.log.dal.pojo.enums.LogStorageMode;
import cd.casic.ci.log.dal.dataobject.LogStatus;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.apache.logging.log4j.util.Strings;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author by mianbin
 * @Classname LogStatusService
 * @Date 2025/3/20 14:27
 */
@Slf4j
@Service
public class LogStatusService {

    @Resource
    private LogStatusMapper logStatusMapper;

    public void finish(String buildId, String tag, String subTag, String jobId, int executeCount, LogStorageMode logStorageMode, Boolean finished) {
        // todo 当死锁的时候重试
        LogStatus logStatus = new LogStatus(buildId, tag, subTag, jobId, logStorageMode.name(), executeCount, finished);
        logStatusMapper.insert(logStatus);
    }

    public void updateStorageMode(String buildId, int executeCount, List<TaskBuildLogProperty> propertyList) {
        // 开始循环更新
        for (TaskBuildLogProperty property : propertyList) {
            // 先弄出更新的mode
            // 写出更新的后置 where 条件，buildId 和 elementId 和 executeCount 相等
            LambdaQueryWrapper<LogStatus> wrapper = Wrappers.<LogStatus>lambdaQuery()
                    .eq(LogStatus::getBuildId, buildId)
                    .eq(LogStatus::getTag, property.getElementId())
                    .eq(LogStatus::getExecuteCount, executeCount);
            LogStatus logStatus = logStatusMapper.selectOne(wrapper);
            logStatus.setMode(property.getLogStorageMode().name());
            logStatusMapper.update(logStatus, wrapper);
        }
    }

    public QueryLogStatus getStorageMode(String buildId, String tag, int executeCount) {
        // 获取 record
        LogStatus record = logStatusMapper.selectOne(Wrappers.<LogStatus>lambdaQuery()
                .eq(LogStatus::getBuildId, buildId)
                .eq(LogStatus::getTag, tag)
                .eq(LogStatus::getExecuteCount, executeCount));

        if (record != null) {
            return new QueryLogStatus(buildId, record.getFinished(), LogStorageMode.parse(record.getMode()));
        } else {
            return new QueryLogStatus(buildId, false, LogStorageMode.UPLOAD);
        }
    }

    public boolean isFinish(String buildId, String tag, String subTag, String jobId, int executeCount) {
        // 判空
        if (tag == null)
            tag = "";
        if (subTag == null)
            subTag = "";
        // #8804 将db中保存字段兜底为空字符串，方便唯一键冲突判断，也就是 jobId
        LambdaQueryWrapper<LogStatus> queryWrapper = Wrappers.<LogStatus>lambdaQuery()
                .eq(LogStatus::getBuildId, buildId)
                .eq(LogStatus::getExecuteCount, executeCount);
        if (!Strings.isBlank(jobId)) {
            queryWrapper.eq(LogStatus::getJobId, jobId)
                    .eq(LogStatus::getTag, "")
                    .eq(LogStatus::getSubTag, "");
        } else {
            queryWrapper
                    .eq(LogStatus::getTag, tag)
                    .eq(LogStatus::getSubTag, subTag);
        }
        LogStatus res = logStatusMapper.selectOne(queryWrapper);
        if (res != null) {
            return res.getFinished();
        }
        return false;
    }

}
