package cd.casic.ci.process.engine.enums;

import lombok.Getter;

import java.util.HashSet;
import java.util.Objects;
import java.util.Set;
@Getter
public enum ContextStateEnum {
    INIT(0,"初始化", new HashSet<>(){
        {
            add(READY);
            add(SUSPEND);
            add(BAD_ENDING);
            add(STOP);
        }
    }),
    READY(1,"就绪", new HashSet<>(){
        {
            add(RUNNING);
            add(SUSPEND);
            add(BAD_ENDING);
            add(STOP);
        }
    }),
    RUNNING(2,"运行", new HashSet<>(){
        {
            add(SUSPEND);
            add(STOP);
            add(HAPPY_ENDING);
            add(BAD_ENDING);
        }
    }),
    SUSPEND(3,"挂起", new HashSet<>(){
        {
            add(INIT);
            add(READY);
            add(RUNNING);
            add(BAD_ENDING);
        }
    }),
    STOP(-1,"停止", new HashSet<>()),
    HAPPY_ENDING(4,"执行成功", new HashSet<>()),
    BAD_ENDING(5,"执行失败", new HashSet<>())
    ;

    private Integer code;
    private String msg;
    /**
     *  包含当前所有合法的下一个状态
     * */
    private Set<ContextStateEnum> nextStep;

    ContextStateEnum(Integer code, String msg, Set<ContextStateEnum> nextStep) {
        this.code = code;
        this.msg = msg;
        this.nextStep = nextStep;
    }
    public static Boolean canGoto(ContextStateEnum from,ContextStateEnum to){
        if (Objects.isNull(from) || Objects.isNull(to)) {
            return false;
        }
        return from.nextStep.contains(to);
    }
    public static ContextStateEnum getByCode(Integer code){
        for (ContextStateEnum value : values()) {
            if (value.getCode().equals(code)) {
                return value;
            }
        }
        return null;
    }
}
