package cd.casic.ci.process.engine.worker;

import cd.casic.ci.common.pipeline.annotation.Plugin;
import cd.casic.ci.process.engine.enums.ContextStateEnum;
import cd.casic.ci.process.engine.manager.RunContextManager;
import cd.casic.ci.process.engine.runContext.BaseRunContext;
import cd.casic.ci.process.engine.runContext.PipelineRunContext;
import cd.casic.ci.process.engine.runContext.TaskRunContext;
import cd.casic.framework.commons.exception.ServiceException;
import cd.casic.framework.commons.exception.enums.GlobalErrorCodeConstants;
import jakarta.annotation.PostConstruct;
import jakarta.annotation.Resource;
import jodd.util.StringUtil;
import lombok.Data;
import org.apache.commons.lang3.StringUtils;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;


@Data

public abstract class BaseWorker implements Runnable{
    // 一些属性
    @Resource
    private RunContextManager contextManager;
    private String contextKey;

    @Override
    public void run() {
        if (StringUtils.isEmpty(contextKey)) {
            throw new ServiceException(GlobalErrorCodeConstants.PIPELINE_ERROR.getCode(),"请设置当前worker的contextKey");
        }
        doWorker(contextKey);
    }

    public void doWorker(String contextKey){
        BaseRunContext context = contextManager.getContext(contextKey);
        if (context instanceof TaskRunContext taskRunContext){
            try {
                taskRunContext.changeContextState(ContextStateEnum.RUNNING);
                execute(taskRunContext);
            } catch (Exception e) {
                taskRunContext.changeContextState(ContextStateEnum.BAD_ENDING);
            }
            // TODO 执行结束修改context的state,并且通知父类
            taskRunContext.changeContextState(ContextStateEnum.HAPPY_ENDING);
        }
    }
    public abstract void execute(TaskRunContext context);

}
