package cd.casic.pipeline.store.api.common;


import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.framework.commons.pojo.PageResult;
import cd.casic.pipeline.store.pojo.common.MarketItem;
import cd.casic.pipeline.store.pojo.common.MarketMainItem;
import cd.casic.pipeline.store.pojo.common.MyStoreComponent;
import cd.casic.pipeline.store.pojo.common.StoreDetailInfo;
import cd.casic.pipeline.store.pojo.common.enums.RdTypeEnum;
import cd.casic.pipeline.store.pojo.common.enums.StoreSortTypeEnum;
import cd.casic.pipeline.store.pojo.common.enums.StoreTypeEnum;
import cd.casic.pipeline.store.pojo.common.media.StoreMediaInfo;
import cd.casic.pipeline.store.pojo.common.test.StoreTestItem;
import cd.casic.pipeline.store.pojo.common.version.StoreDeskVersionItem;
import cd.casic.pipeline.store.pojo.common.version.StoreShowVersionInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Set;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.AUTH_HEADER_USER_ID;


@Tag(name = "USER_STORE_COMPONENT", description = "研发商店-组件查询")
@RestController
@RequestMapping("/user/store/components")
public interface UserStoreComponentQueryResource {

    @Operation(summary = "根据用户获取工作台组件列表")
    @GetMapping("/desk/types/{storeType}/component/list")
    PageResult<MyStoreComponent> getMyComponents(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            String storeType,
            @Parameter(description = "组件名称", required = false)
            @RequestParam("name")
            String name,
            @Parameter(description = "页码", required = true)
            @RequestParam("page")
            Integer page,
            @Parameter(description = "每页数量", required = true)
            @RequestParam("pageSize")
            Integer pageSize
    );

    @Operation(summary = "根据组件标识获取组件版本列表")
    @GetMapping("/desk/types/{storeType}/codes/{storeCode}/component/version/list")
    PageResult<StoreDeskVersionItem> getComponentVersionsByCode(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            String storeType,
            @Parameter(description = "组件代码", required = true)
            @PathVariable("storeCode")
            String storeCode,
            @Parameter(description = "页码", required = true)
            @RequestParam("page")
            Integer page,
            @Parameter(description = "每页数量", required = true)
            @RequestParam("pageSize")
            Integer pageSize
    );

    @Operation(summary = "根据组件ID获取组件详情")
    @GetMapping("/types/{storeType}/ids/{storeId}/component/detail")
    CommonResult<StoreDetailInfo> getComponentDetailInfoById(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            String storeType,
            @Parameter(description = "组件ID", required = true)
            @PathVariable("storeId")
            String storeId
    );

    @Operation(summary = "根据组件代码获取组件详情")
    @GetMapping("/types/{storeType}/codes/{storeCode}/component/detail")
    CommonResult<StoreDetailInfo> getComponentDetailInfoByCode(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            String storeType,
            @Parameter(description = "组件代码", required = true)
            @PathVariable("storeCode")
            String storeCode
    );

    @Operation(summary = "获取研发商店首页组件的数据")
    @GetMapping("/types/{storeType}/component/main/page/list")
    CommonResult<List<MarketMainItem>> getMainPageComponents(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            String storeType,
            @Parameter(description = "项目代码", required = false)
            @RequestParam("projectCode")
            String projectCode,
            @Parameter(description = "实例ID", required = false)
            @RequestParam("instanceId")
            String instanceId,
            @Parameter(description = "页码", required = true)
            @RequestParam("page")
            Integer page,
            @Parameter(description = "每页数量", required = true)
            @RequestParam("pageSize")
            Integer pageSize
    );

    @Operation(summary = "根据条件查询组件列表")

    @GetMapping("/types/{storeType}/component/list")
    PageResult<MarketItem> queryComponents(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            String storeType,
            @Parameter(description = "项目代码", required = false)
            @RequestParam("projectCode")
            String projectCode,
            @Parameter(description = "搜索关键字", required = false)
            @RequestParam("keyword")
            String keyword,
            @Parameter(description = "分类ID", required = false)
            @RequestParam("classifyId")
            String classifyId,
            @Parameter(description = "标签ID", required = false)
            @RequestParam("labelId")
            String labelId,
            @Parameter(description = "范畴ID", required = false)
            @RequestParam("categoryId")
            String categoryId,
            @Parameter(description = "评分", required = false)
            @RequestParam("score")
            Integer score,
            @Parameter(description = "研发来源类型", required = false)
            @RequestParam("rdType")
            RdTypeEnum rdType,
            @Parameter(description = "是否推荐标识 true：推荐，false：不推荐", required = false)
            @RequestParam("recommendFlag")
            Boolean recommendFlag,
            @Parameter(description = "是否已在该项目安装 true：是，false：否", required = false)
            @RequestParam("installed")
            Boolean installed,
            @Parameter(description = "是否需要更新标识 true：需要，false：不需要", required = false)
            @RequestParam("updateFlag")
            Boolean updateFlag,
            @Parameter(description = "是否查询项目下组件标识", required = true)
            @RequestParam("queryProjectComponentFlag")
            Boolean queryProjectComponentFlag,
            @Parameter(description = "排序", required = false)
            @RequestParam("sortType")
            StoreSortTypeEnum sortType,
            @Parameter(description = "实例ID", required = false)
            @RequestParam("instanceId")
            String instanceId,
            @Parameter(description = "是否查测试中版本 true：是，false：否", required = false)
            @RequestParam("queryTestFlag")
            Boolean queryTestFlag,
            @Parameter(description = "页码", required = true)
            @RequestParam("page")
            Integer page,
            @Parameter(description = "每页数量", required = true)
            @RequestParam("pageSize")
            Integer pageSize
    );

    @Operation(summary = "根据组件标识获取组件回显版本信息")
    @GetMapping("/types/{storeType}/codes/{storeCode}/component/showVersionInfo")
    CommonResult<StoreShowVersionInfo> getComponentShowVersionInfo(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            String storeType,
            @Parameter(description = "组件代码", required = true)
            @PathVariable("storeCode")
            String storeCode
    );

    @Operation(summary = "获取组件测试信息")
    @GetMapping("/types/{storeType}/codes/{storeCode}/component/test/info/get")
    CommonResult<Set<StoreTestItem>> getStoreTestInfo(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "组件代码", required = true)
            @PathVariable("storeCode")
            String storeCode
    );

    @Operation(summary = "获取组件媒体信息")
    @GetMapping("/types/{storeType}/codes/{storeCode}/component/media/info/get")
    CommonResult<List<StoreMediaInfo>> getStoreMediaInfo(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "组件代码", required = true)
            @PathVariable("storeCode")
            String storeCode
    );
}