package cd.casic.pipeline.store.api.image;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.store.pojo.common.publication.StoreProcessInfo;
import cd.casic.pipeline.store.pojo.image.request.MarketImageRelRequest;
import cd.casic.pipeline.store.pojo.image.request.MarketImageUpdateRequest;
import cd.casic.pipeline.store.pojo.image.request.OfflineMarketImageReq;
import cd.casic.pipeline.store.pojo.image.response.ImageAgentTypeInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.AUTH_HEADER_USER_ID;

@Tag(name = "USER_MARKET_IMAGE", description = "研发商店-镜像")
@RestController
@RequestMapping("/user/market")
public interface UserImageReleaseResource {

    @Operation(summary = "关联镜像")
    @PostMapping("/image/imageCodes/{imageCode}/store/rel")
    CommonResult<String> addMarketImage(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "镜像代码", required = true)
            @PathVariable("imageCode")
            String imageCode,
            @Parameter(description = "关联镜像请求报文体", required = true)
            @Valid
            MarketImageRelRequest marketImageRelRequest
    );

    @Operation(summary = "上架/升级镜像")
    @PutMapping("/desk/image/release")
    CommonResult<String> updateMarketImage(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "上架镜像请求报文体", required = true)
            MarketImageUpdateRequest marketImageUpdateRequest
    );

    @Operation(summary = "下架镜像")
    @PutMapping("/desk/image/offline/imageCodes/{imageCode}/versions")
    CommonResult<Boolean> offlineMarketImage(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "镜像Code", required = true)
            @PathVariable("imageCode")
            String imageCode,
            @Parameter(description = "下架镜像请求报文体", required = true)
            OfflineMarketImageReq offlineMarketImageReq
    );

    @Operation(summary = "根据镜像ID获取镜像版本进度")
    @GetMapping("/desk/image/release/process/imageIds/{imageId}")
    CommonResult<StoreProcessInfo> getProcessInfo(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "镜像Id", required = true)
            @PathVariable("imageId")
            String imageId
    );

    @Operation(summary = "取消发布镜像")
    @PutMapping("/desk/image/release/cancel/imageIds/{imageId")
    CommonResult<Boolean> cancelRelease(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "镜像Id", required = true)
            @PathVariable("imageId")
            String imageId
    );

    @Operation(summary = "重新验证镜像")
    @PutMapping("/desk/image/release/recheck/imageIds/{imageId}")
    CommonResult<Boolean> recheck(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "镜像Id", required = true)
            @PathVariable("imageId")
            String imageId
    );

    @Operation(summary = "确认镜像通过测试")
    @PutMapping("/desk/image/release/passTest/imageIds/{imageId}")
    CommonResult<Boolean> passTest(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "镜像Id", required = true)
            @PathVariable("imageId")
            String imageId
    );

    @Operation(summary = "获取镜像支持的机器类型列表")
    @GetMapping("/image/agentType/list")
    CommonResult<List<ImageAgentTypeInfo>> getImageAgentTypes(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId
    );
}