package cd.casic.pipeline.store.pojo.common.handler;

public interface Handler<T extends HandlerRequest> {

    /**
     * 能否满足运行条件
     */
    boolean canExecute(T handlerRequest);

    /**
     * 核心处理逻辑
     */
    void execute(T handlerRequest);

    /**
     * 执行总入口，将调用canExecute判断是否满足再执行execute函数，
     * 并将chain链式传递handlerRequest继续执行下去
     */
    default void doExecute(T handlerRequest, HandlerChain<T> chain) {
        if (canExecute(handlerRequest)) {
            execute(handlerRequest);
        }
        chain.handleRequest(handlerRequest);
    }
}